==> robodoc_4.0.18.orig.tar.gz: robodoc-4.0.18/Source/globals.c <==
/****h* ROBODoc/Globals
 * FUNCTION
 *   A number of global variables.
 * TODO
 *   Documentation.
 *****
 * $Id: globals.c,v 1.11 2003/12/30 17:39:36 gumpu Exp $
 */

#include <stdio.h>
#include "robodoc.h"
#include "globals.h"
#include "links.h"

#ifdef DMALLOC
#include <dmalloc.h>
#endif


unsigned int        link_index_size = 0;
struct RB_link    **link_index = NULL;

/* Pointer to the name of the current file that is being analysed,
   use by RB_Panic */

char               *current_file = 0;

/****v* Globals/document_title
 * NAME
 *   documentat_title -- title for the documentation.
 * PURPOSE
 *   Used as the title for master index files or for latex documentation.
 * SOURCE
 */

char               *document_title = NULL;

/******/


/****v* Globals/output_mode [2.0]
 * NAME
 *   output_mode -- the mode of output
 * FUNCTION
 *   Controls which type of output will be generated.
 * SOURCE
 */

T_RB_DocType        output_mode = ASCII;

/*******/


/****v* Globals/course_of_action [2.0]
 * NAME
 *   course_of_action
 * FUNCTION
 *   Global Variable that defines the course of action.
 * SOURCE
 */

long                course_of_action = 0;

/*******/


/****v* Globals/line_buffer [2.0]
 * NAME
 *   line_buffer -- global line buffer
 * FUNCTION
 *   Temporary storage area for lines
 *   that are read from an input file.
 * SOURCE
 */

char                line_buffer[MAX_LINE_LEN];

/*******/


/****v* Globals/line_number [2.0]
 * NAME
 *   line_number -- global line counter
 * PURPOSE
 *   Keeps track of the number of lines that are read from the source file.
 * AUTHOR
 *   Koessi
 * SOURCE
 */

int                 line_number = 0;

/*******/

/*
 * Global variables 
 */
/* TODO  Document these. */

char               *source_file;        /* DCD */
char               *whoami = NULL;      /* me,myself&i */
int                 tab_size = 8;
char                doc_base[1024];     /* TODO  Obsolete Remove */

/****i* Globals/RB_Close_The_Shop [3.0b]
 * NAME
 *   RB_Close_The_Shop -- free resources.
 * SYNOPSIS
 *   void RB_Close_The_Shop ()
 * FUNCTION
 *   Frees all resources used by robodoc.
 * SEE ALSO
 *   RB_Free_Header(), RB_Free_Link()
 * SOURCE
 */

void
RB_Close_The_Shop( void )
{
/* TODO    if (link_index) { free(link_index); } */
}

/******/

==> robodoc-4.99.6.tar.gz: robodoc-4.99.6/Source/globals.c <==
/****h* ROBODoc/Globals
 * FUNCTION
 *   A number of global variables.
 * TODO
 *   Documentation.
 *****
 * $Id: globals.c,v 1.13 2004/06/16 20:31:49 gumpu Exp $
 */

#include <stdio.h>
#include "robodoc.h"
#include "globals.h"
#include "links.h"

#ifdef DMALLOC
#include <dmalloc.h>
#endif

int                 number_of_warnings = 0;

/* Pointer to the name of the current file that is being analysed,
   use by RB_Panic */

char               *current_file = 0;

/****v* Globals/document_title
 * NAME
 *   documentat_title -- title for the documentation.
 * PURPOSE
 *   Used as the title for master index files or for latex documentation.
 * SOURCE
 */

char               *document_title = NULL;

/******/


/****v* Globals/output_mode [2.0]
 * NAME
 *   output_mode -- the mode of output
 * FUNCTION
 *   Controls which type of output will be generated.
 * SOURCE
 */

T_RB_DocType        output_mode = ASCII;

/*******/


/****v* Globals/course_of_action [2.0]
 * NAME
 *   course_of_action
 * FUNCTION
 *   Global Variable that defines the course of action.
 * SOURCE
 */

long                course_of_action = 0;

/*******/


/****v* Globals/line_buffer [2.0]
 * NAME
 *   line_buffer -- global line buffer
 * FUNCTION
 *   Temporary storage area for lines
 *   that are read from an input file.
 * SOURCE
 */

char                line_buffer[MAX_LINE_LEN];

/*******/


/****v* Globals/line_number [2.0]
 * NAME
 *   line_number -- global line counter
 * PURPOSE
 *   Keeps track of the number of lines that are read from the source file.
 * AUTHOR
 *   Koessi
 * SOURCE
 */

int                 line_number = 0;

/*******/

/*
 * Global variables 
 */
/* TODO  Document these. */

char               *source_file;        /* DCD */
char               *whoami = NULL;      /* me,myself&i */
int                 tab_size = 8;
char                doc_base[1024];     /* TODO  Obsolete Remove */

/****i* Globals/RB_Close_The_Shop [3.0b]
 * NAME
 *   RB_Close_The_Shop -- free resources.
 * SYNOPSIS
 *   void RB_Close_The_Shop ()
 * FUNCTION
 *   Frees all resources used by robodoc.
 * SEE ALSO
 *   RB_Free_Header(), RB_Free_Link()
 * SOURCE
 */

void
RB_Close_The_Shop( void )
{
/* TODO    if (link_index) { free(link_index); } */
}

/******/
